(citation)=

# Citing tstrait

If you use `tstrait` in your research project, please cite the following paper:

- Daiki Tagami, Gertjan Bisschop, and Jerome Kelleher (2024), *tstrait: a quantitative trait simulator for ancestral recombination graphs*,Bioinformatics, Volume 40, Issue 6. https://doi.org/10.1093/bioinformatics/btae334

Bibtex records:

```bibtex
@article{10.1093/bioinformatics/btae334,
    author = {Tagami, Daiki and Bisschop, Gertjan and Kelleher, Jerome},
    title = "{tstrait: a quantitative trait simulator for ancestral recombination graphs}",
    journal = {Bioinformatics},
    volume = {40},
    number = {6},
    pages = {btae334},
    year = {2024},
    month = {05},
    doi = {10.1093/bioinformatics/btae334},
}
```